package com.autentia.tutoriales.icefaces.beans;


import java.util.List;
import javax.faces.component.UIData;
import javax.faces.event.ValueChangeEvent;
import javax.naming.NamingException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import com.autentia.tutoriales.modelo.entidades.Categoria;
import com.autentia.tutoriales.modelo.services.Dao;
import com.autentia.tutoriales.modelo.services.DaoImpl;
import com.autentia.tutoriales.modelo.services.FilterParameter;
import com.autentia.tutoriales.modelo.util.EjbLocator;

/**
 * Managed Bean para categorías. 
 * @author fjmpaez
 *
 */

public class CategoryCtrl {
	private static final Log log = LogFactory.getLog(CategoryCtrl.class);
	
	private String sortColumn = "nombre";
	private boolean sortAscending = true;
	private UIData tabla;
	
	Dao dao;
	
	private String search="";
	
	public CategoryCtrl() {
		log.debug("Constructor:CategoryCtrl");
		try {
			dao = EjbLocator.lookupLocalBean(DaoImpl.class);
		} catch (NamingException e) {
			log.error ("Error al iniciar el controlador: ", e);
		}
	}
	
	public List<Categoria> getAll() {		
		if("".equals(search)) {
			return dao.findAll(Categoria.class, getSortColumn(), isSortAscending());
		} else {
			return dao.findAllAndFilterLike(Categoria.class, sortColumn, sortAscending,true, 
					new FilterParameter("nombre",search), 
					new FilterParameter("descripcion",search));
		}
	}
	
	
	public String getSortColumn() {
		return sortColumn;
	}
	public void setSortColumn(String sortColumn) {
		this.sortColumn = sortColumn;
	}
	public boolean isSortAscending() {
		return sortAscending;
	}
	public void setSortAscending(boolean sortAscending) {
		this.sortAscending = sortAscending;
	}

	public UIData getTabla() {
		return tabla;
	}

	public void setTabla(UIData tabla) {
		this.tabla = tabla;
	}
	
	public String getSearch() {
		return search;
	}

	public void setSearch(String search) {
		this.search = search;
	}
	
	/**
	 * Este método asegura que tras una búsqueda, la tabla vuelva
	 * a mostrar la primera página.
	 * @param event
	 */	
	public void changeSearch(ValueChangeEvent event) {
		tabla.setFirst(0);
	}
	
}
